wine.com

What state will you be shipping to?
I'm shipping to
CONTINUE
Please select your shipping state to proceed. Your browser is currently set to block Cookies which are required for this website to function properly. Privacy Policy
why?
close
Due to state wine regulations, our assortment can vary across the U.S. Please select the state you are shipping to for the best shopping experience.
Welcome to our online Wine.com Customer Care. We are happy to assist you!

CALL US: 1-800-592-5870

HOURS:
Monday-Saturday: 6:00am-6:00pm, Pacific time
Sunday: 7:00am-4:00pm, Pacific time

EMAIL US:

Create and/or login to your Wine.com account and follow the steps below.

- Step 1 – Directly below, in the My question is about: section, type in the subject of your question and click NEXT
- Step 2 – On the next page, below the Can’t find your Question below? click on the Submit Your Question button
- Step 3 – Enter in the details of your question and then click on the Submit Question button

Ask a Question | View and Update Your Existing Questions
Step 1 of 3
My question is about

IMPORTANT QUESTIONS | VIEWS
--- | ---
| 05. WEATHER HOLDS - Why is my order on hold and what is the cost to ship now? | 1191
View all important questions

MOST COMMON QUESTIONS | VIEWS
--- | ---
01. Shipping Regulations - Where does Wine.com ship wine? | 424587
01. WINE.COM CUSTOMER SERVICE - What are your HOURS and PHONE NUMBER? | 144524
03. Shipping Rates - What do you charge for shipping? | 42690
01. Tracking - How can I check on an order status and delivery? | 21023
06. Wine Club - How do I make changes to a Wine Club subscription? | 20516
09. Promotion Codes - How do I redeem a promotion code? | 14726
04. Wine Club - When are wine club orders shipped each month? | 11765
04. Multiple Charges - Why is my online statement showing more than one charge? | 9281
05. Unsubscribing Your Email Address - How do I opt out from email offers? | 8796
03. Tracking and Viewing Your Orders - How can I view and track my orders? | 6628
View all common questions

Please login or create an account to create a wine list.
Thank you! You will complete your StewardShip Free Trial signup at checkout x
The image was successfully added